require 'anvil/client'
require 'anvil/vulnerability'
require 'spec_helper'

describe Anvil::Vulnerability do
  let(:client) { Anvil::Client.new('foobar', 'staging') }
  describe '.initialize' do
    context 'with proper params' do
      it do
        expect(Anvil::Vulnerability.new(client))
          .to be_an_instance_of Anvil::Vulnerability
      end
    end

    context 'with invalid params' do
      it do
        expect { Anvil::Vulnerability.new('foobar') }
          .to raise_error ArgumentError
      end
    end
  end

  describe 'create!' do
    let(:params) do
      { client_impact: 'impacto', project_id: 1826, vulnerability_model_id: 10,
        failure_type: 'code_review', code_review_code: 'code',
        evidences: ['/myfilse/image.png'] }
    end

    before do
      conn = double
      expect(Faraday).to receive(:new).and_return(conn)
      expect(conn).to receive(:post).and_return(201)
      expect(Faraday::UploadIO).to receive(:new).and_return('file')
    end

    it do
      expect(Anvil::Vulnerability.new(client).create!(params)).to eq 201
    end
  end
end
